@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -22,14 +22,15 @@
 import uuid
 from email.message import EmailMessage
 
-from mock import Mock, patch
 from django.contrib.auth.models import User
-from hyperkitty.utils import reverse
+
 from django_mailman3.tests.utils import FakeMMList, FakeMMMember
+from mock import Mock, patch
 
 from hyperkitty.lib.incoming import add_to_list
-from hyperkitty.models import MailingList, ArchivePolicy
+from hyperkitty.models import ArchivePolicy, MailingList
 from hyperkitty.tests.utils import SearchEnabledTestCase
+from hyperkitty.utils import reverse
 
 
 class SearchViewsTestCase(SearchEnabledTestCase):
